@@ -14,11 +14,9 @@
 from typing import Optional
 
 import torch
-from deprecate import deprecated, void
 from torch import Tensor
 
 from torchmetrics.functional.classification.stat_scores import _reduce_stat_scores, _stat_scores_update
-from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.enums import AverageMethod as AvgMethod
 from torchmetrics.utilities.enums import MDMCAverageMethod
 
@@ -74,8 +72,8 @@ def _fbeta_compute(
         precision = _safe_divide(tp.float(), tp + fp)
         recall = _safe_divide(tp.float(), tp + fn)
 
-    num = (1 + beta ** 2) * precision * recall
-    denom = beta ** 2 * precision + recall
+    num = (1 + beta**2) * precision * recall
+    denom = beta**2 * precision + recall
     denom[denom == 0.0] = 1.0  # avoid division by 0
 
     # if classes matter and a given class is not present in both the preds and the target,
@@ -140,11 +138,12 @@ def fbeta_score(
 
     The reduction method (how the precision scores are aggregated) is controlled by the
     ``average`` parameter, and additionally by the ``mdmc_average`` parameter in the
-    multi-dimensional multi-class case. Accepts all inputs listed in :ref:`references/modules:input types`.
+    multi-dimensional multi-class case. Accepts all inputs listed in :ref:`pages/classification:input types`.
 
     Args:
         preds: Predictions from model (probabilities, logits or labels)
         target: Ground truth values
+        beta: beta coefficient
         average:
             Defines the reduction that is applied. Should be one of the following:
 
@@ -161,7 +160,7 @@ def fbeta_score(
             .. note:: What is considered a sample in the multi-dimensional multi-class case
                 depends on the value of ``mdmc_average``.
 
-            .. note:: If ``'none'`` and a given class doesn't occur in the `preds` or `target`,
+            .. note:: If ``'none'`` and a given class doesn't occur in the ``preds`` or ``target``,
                 the value for the class will be ``nan``.
 
         mdmc_average:
@@ -173,10 +172,10 @@ def fbeta_score(
                 - ``'samplewise'``: In this case, the statistics are computed separately for each
                   sample on the ``N`` axis, and then averaged over samples.
                   The computation for each sample is done by treating the flattened extra axes ``...``
-                  (see :ref:`references/modules:input types`) as the ``N`` dimension within the sample,
+                  (see :ref:`pages/classification:input types`) as the ``N`` dimension within the sample,
                   and computing the metric for the sample based on that.
                 - ``'global'``: In this case the ``N`` and ``...`` dimensions of the inputs
-                  (see :ref:`references/modules:input types`)
+                  (see :ref:`pages/classification:input types`)
                   are flattened into a new ``N_X`` sample axis, i.e. the inputs are treated as if they
                   were ``(N_X, C)``. From here on the ``average`` parameter applies as usual.
 
@@ -198,7 +197,7 @@ def fbeta_score(
         multiclass:
             Used only in certain special cases, where you want to treat inputs as a different type
             than what they appear to be. See the parameter's
-            :ref:`documentation section <references/modules:using the multiclass parameter>`
+            :ref:`documentation section <pages/classification:using the multiclass parameter>`
             for a more detailed explanation and examples.
 
     Return:
@@ -245,32 +244,6 @@ def fbeta_score(
     return _fbeta_compute(tp, fp, tn, fn, beta, ignore_index, average, mdmc_average)
 
 
-@deprecated(target=fbeta_score, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-def fbeta(
-    preds: Tensor,
-    target: Tensor,
-    beta: float = 1.0,
-    average: str = "micro",
-    mdmc_average: Optional[str] = None,
-    ignore_index: Optional[int] = None,
-    num_classes: Optional[int] = None,
-    threshold: float = 0.5,
-    top_k: Optional[int] = None,
-    multiclass: Optional[bool] = None,
-) -> Tensor:
-    r"""
-    Computes f_beta metric.
-
-    .. deprecated:: v0.7
-        Use :class:`torchmetrics.functional.f1_score`. Will be removed in v0.8.
-
-    Example::
-        >>> fbeta(torch.tensor([0, 2, 1, 0, 0, 1]), torch.tensor([0, 1, 2, 0, 1, 2]), num_classes=3, beta=0.5)
-        tensor(0.3333)
-    """
-    return void(preds, target, beta, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass)
-
-
 def f1_score(
     preds: Tensor,
     target: Tensor,
@@ -296,11 +269,12 @@ def f1_score(
 
     The reduction method (how the precision scores are aggregated) is controlled by the
     ``average`` parameter, and additionally by the ``mdmc_average`` parameter in the
-    multi-dimensional multi-class case. Accepts all inputs listed in :ref:`references/modules:input types`.
+    multi-dimensional multi-class case. Accepts all inputs listed in :ref:`pages/classification:input types`.
 
     Args:
         preds: Predictions from model (probabilities, logits or labels)
         target: Ground truth values
+        beta: it is ignored
         average:
             Defines the reduction that is applied. Should be one of the following:
 
@@ -317,24 +291,23 @@ def f1_score(
             .. note:: What is considered a sample in the multi-dimensional multi-class case
                 depends on the value of ``mdmc_average``.
 
-            .. note:: If ``'none'`` and a given class doesn't occur in the `preds` or `target`,
+            .. note:: If ``'none'`` and a given class doesn't occur in the ``preds`` or ``target``,
                 the value for the class will be ``nan``.
 
         mdmc_average:
             Defines how averaging is done for multi-dimensional multi-class inputs (on top of the
             ``average`` parameter). Should be one of the following:
 
-            - ``None`` [default]: Should be left unchanged if your data is not multi-dimensional
-              multi-class.
+            - ``None`` [default]: Should be left unchanged if your data is not multi-dimensional multi-class.
 
             - ``'samplewise'``: In this case, the statistics are computed separately for each
               sample on the ``N`` axis, and then averaged over samples.
               The computation for each sample is done by treating the flattened extra axes ``...``
-              (see :ref:`references/modules:input types`) as the ``N`` dimension within the sample,
+              (see :ref:`pages/classification:input types`) as the ``N`` dimension within the sample,
               and computing the metric for the sample based on that.
 
             - ``'global'``: In this case the ``N`` and ``...`` dimensions of the inputs
-              (see :ref:`references/modules:input types`)
+              (see :ref:`pages/classification:input types`)
               are flattened into a new ``N_X`` sample axis, i.e. the inputs are treated as if they
               were ``(N_X, C)``. From here on the ``average`` parameter applies as usual.
 
@@ -359,7 +332,7 @@ def f1_score(
         multiclass:
             Used only in certain special cases, where you want to treat inputs as a different type
             than what they appear to be. See the parameter's
-            :ref:`documentation section <references/modules:using the multiclass parameter>`
+            :ref:`documentation section <pages/classification:using the multiclass parameter>`
             for a more detailed explanation and examples.
 
     Return:
@@ -379,31 +352,3 @@ def f1_score(
     return fbeta_score(
         preds, target, 1.0, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass
     )
-
-
-@deprecated(target=f1_score, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-def f1(
-    preds: Tensor,
-    target: Tensor,
-    beta: float = 1.0,
-    average: str = "micro",
-    mdmc_average: Optional[str] = None,
-    ignore_index: Optional[int] = None,
-    num_classes: Optional[int] = None,
-    threshold: float = 0.5,
-    top_k: Optional[int] = None,
-    multiclass: Optional[bool] = None,
-) -> Tensor:
-    """Computes F1 metric. F1 metrics correspond to a equally weighted average of the precision and recall scores.
-
-    .. deprecated:: v0.7
-        Use :class:`torchmetrics.functional.f1_score`. Will be removed in v0.8.
-
-    Example:
-        >>> from torchmetrics.functional import f1
-        >>> target = torch.tensor([0, 1, 2, 0, 1, 2])
-        >>> preds = torch.tensor([0, 2, 1, 0, 0, 1])
-        >>> f1(preds, target, num_classes=3)
-        tensor(0.3333)
-    """
-    return void(preds, target, beta, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass)
