@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict
+from typing import Any
 
 import torch
 from torch import Tensor
@@ -74,7 +74,7 @@ class TweedieDevianceScore(Metric):
     def __init__(
         self,
         power: float = 0.0,
-        **kwargs: Dict[str, Any],
+        **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
         if 0 < power < 1:
